S3FS
====

S3FS is a `PyFilesystem interface <https://docs.pyfilesystem.org/>`__ to
Amazon S3 cloud storage.

As a PyFilesystem concrete class, S3FS allows you to work with S3 in the
same as any other supported filesystem.

`Documentation <http://fs-s3fs.readthedocs.io/en/latest/>`__
